0.0.4
=====

- Include a MANIFEST.in to ensure docs are packaged.

0.0.3
=====
- Fix packaging error

0.0.2
=====

- Fix an issue when repointing foreign keys on model classes with custom
  fields which use the django.db.models.SubfieldBase metaclass
- Fix an issue migrating from Django 1.2 to 1.3.

0.0.1
=====

- Initial version